@@ -14,10 +14,6 @@ CONFIGS_DIR = TEST_DIR / "resources" / "test_configs"
 class TestEphysJobConfigs(unittest.TestCase):
     """Tests ephys job pipeline methods"""
 
-    metadata_schemas_url = (
-        "https://raw.githubusercontent.com/AllenNeuralDynamics/"
-        "data_schema/main/schemas"
-    )
     code_repo_url = "https://github.com/AllenNeuralDynamics/aind-data-transfer"
 
     def test_conf_loads(self):
@@ -47,7 +43,6 @@ class TestEphysJobConfigs(unittest.TestCase):
                 "gcp_bucket": "aind-data-dev",
                 "gcp_prefix": "test_20221001",
                 "codeocean_domain": "https://acmecorp.codeocean.com",
-                "metadata_schemas": self.metadata_schemas_url,
                 "code_repo_location": self.code_repo_url,
             },
             "data": {"name": "openephys"},
@@ -101,7 +96,6 @@ class TestEphysJobConfigs(unittest.TestCase):
                 "gcp_bucket": "aind-data-dev",
                 "gcp_prefix": "ecephys_625463_2022-10-06_10-14-25",
                 "codeocean_domain": "https://acmecorp.codeocean.com",
-                "metadata_schemas": self.metadata_schemas_url,
                 "code_repo_location": self.code_repo_url,
             },
             "data": {"name": "openephys"},
@@ -139,10 +133,7 @@ class TestEphysJobConfigs(unittest.TestCase):
 
 
 class TestImagingJobConfigs(unittest.TestCase):
-    metadata_schemas_url = (
-        "https://raw.githubusercontent.com/AllenNeuralDynamics/"
-        "data_schema/main/schemas"
-    )
+
     code_repo_url = "https://github.com/AllenNeuralDynamics/aind-data-transfer"
 
     """Basic config loads test"""
@@ -162,7 +153,6 @@ class TestImagingJobConfigs(unittest.TestCase):
             "endpoints": {
                 "raw_data_dir": raw_data_dir,
                 "dest_data_dir": "s3://aind-transfer-test/exaSPIM_125L_2022-08-05_17-25-36",
-                "metadata_schemas": self.metadata_schemas_url,
                 "code_repo_location": self.code_repo_url,
             },
             "data": {"name": "imaging"},
